:code:`links`
^^^^^^^^^^^^^

    **Type:** :code:`dict`

    **Description:** Set the list of links which can be used/called by the system when needed.

    .. note::
        The objective of this index is to avoid hardcoded links when the configuration file is readable.


:code:`links[api_date_format]`
""""""""""""""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://pyfunceble.funilrys.com/api/date-format`

    **Description:** Set the link to use when we share logs.


:code:`links[api_no_referer]`
""""""""""""""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://pyfunceble.funilrys.com/api/no-referer`

    **Description:** Set the link to use when we share logs.

:code:`links[config]`
"""""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://raw.githubusercontent.com/funilrys/PyFunceble/dev/.PyFunceble_production.yaml`

    **Description:** Set the upstream link to the configuration file.

:code:`links[dir_structure]`
""""""""""""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://raw.githubusercontent.com/funilrys/PyFunceble/dev/dir_structure_production.json`

    **Description:** Set the upstream link to the directory structure dump file.

:code:`links[iana]`
"""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://raw.githubusercontent.com/funilrys/PyFunceble/dev/iana-domains-db.json`

    **Description:** Set the upstream link to the IANA zone file configuration file.

:code:`links[mariadb]`
""""""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://raw.githubusercontent.com/funilrys/PyFunceble/dev/db_types/mariadb.sql`

    **Description:** Set the upstream link to the MariaDB table constructor file.


:code:`links[mysql]`
""""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://raw.githubusercontent.com/funilrys/PyFunceble/dev/db_types/mysql.sql`

    **Description:** Set the upstream link to the MySQL table constructor file.

:code:`links[psl]`
""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://raw.githubusercontent.com/funilrys/PyFunceble/dev/public-suffix.json`

    **Description:** Set the upstream link to the public suffix database file.


:code:`links[repo]`
"""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://github.com/funilrys/PyFunceble`

    **Description:** Set the upstream link to the repository.

:code:`links[requirements]`
"""""""""""""""""""""""""""

    **Type:** :code:`string`

    **Default value:** :code:`https://raw.githubusercontent.com/funilrys/PyFunceble/dev/requirements.txt`

    **Description:** Set the upstream link to the :code:`requirements.txt` file.
